import { DataGrid } from 'tde-datagrid';
import { LabIcon } from '@jupyterlab/ui-components';
export declare class PaintedGrid extends DataGrid {
    constructor(options: PaintedGrid.IOptions);
    /**
     * Get the extra styles of the PaintedGrid.
     */
    get extraStyle(): PaintedGrid.ExtraStyle;
    /**
     * Set the styles of the painted grid.
     */
    set extraStyle(value: PaintedGrid.ExtraStyle);
    /**
     * @override paints on the ghost row and column as well after painting the other regions.
     * Paint the grid content for the given dirty rect.
     *
     * The rect should be expressed in valid viewport coordinates.
     *
     * This is the primary paint entry point. The individual `_draw*`
     * methods should not be invoked directly. This method dispatches
     * to the drawing methods in the correct order.
     */
    protected paintContent(rx: number, ry: number, rw: number, rh: number): void;
    /**
     * Primary entry point for painting additional graphics on top of
     * the base data grid graphics.
     */
    private _paintAddons;
    /**
     * Draw the ghost row.
     */
    private _drawGhostRow;
    /**
     * Draw the ghost column.
     */
    private _drawGhostColumn;
    private _drawGhostRowHeader;
    private _drawGhostColumnHeader;
    private _drawGhostRowIcon;
    private _drawColumnIcon;
    private _drawOverCorner;
    private _extraStyle;
}
/**
 * Namespace for class statics.
 */
export declare namespace PaintedGrid {
    /**
     * The options for creating a new PaintedGrid.
     */
    interface IOptions extends DataGrid.IOptions {
        extraStyle?: ExtraStyle;
    }
    /**
     * The extra styling options for a painted grid.
     */
    type ExtraStyle = {
        /**
         * The color of the ghost row.
         *
         * NOTE: This is painted on top of the last row and so
         * in most cases an opaque color is chosen.
         */
        ghostRowColor?: string;
        /**
         * The color of the ghost column.
         *
         * NOTE: This is painted on top of the last column and so
         * in most cases an opaque color is chosen.
         */
        ghostColumnColor?: string;
        /**
         * A object mapping data types to Icons.
         */
        icons?: {
            [key: string]: IIconArgs;
        };
    };
    type IIconArgs = {
        /**
         * The icon to paint on the grid.
         */
        icon: LabIcon;
        /**
         * The fill color for the icon.
         */
        color: string;
        /**
         * How far left to center the Icon as a proportion of the width of the cell.
         */
        left?: number;
        /**
         * How far down to center the Icon as a proportion of the height of the cell.
         */
        top?: number;
        /**
         * The height of the Icon as a proportion of the height of the cell.
         * NOTE: If the width of the cell is less than the height, then this
         * will be calculated as a proportion of the width.
         */
        height?: number;
    };
}
